
#include "THERMO_Routines.h"
#include "MCP9600.h"

char tmp_data[10];
/*******************************************************************************
* Function Write_MCP9600_Data(RegAddr)
* ------------------------------------------------------------------------------
* Overview: Function writes Data to MCP9600
* Input: Register address, data
* Output: Nothing
*******************************************************************************/
void Write_MCP9600_Data(char RegAddr, char _data)
{
  tmp_data[0] = RegAddr;
  tmp_data[1] = _data;

  I2C_Start();
  I2C_Write( MCP9600_I2C_ADDR );
  I2C_Write( tmp_data[ 0 ] );
  I2C_Write( tmp_data[ 1 ] );
  I2C_Stop();
}

/*******************************************************************************
* Function Read_MCP9600_Data(RegAddr)
* ------------------------------------------------------------------------------
* Overview: Function gets Data from MCP9600
* Input: Register address
* Output: Value from desired register
*******************************************************************************/
char Read_MCP9600_Data(char RegAddr)
{
  tmp_data[0] = RegAddr;                                                        // Register address

  I2C_Start();
  I2C_Write( MCP9600_I2C_ADDR );
  I2C_Write( tmp_data[ 0 ] );
  I2C_Stop();
  Delay_us( 50 );
  I2C_Start();
  I2C_Write( MCP9600_I2C_ADDR | 1 );
  tmp_data[ 0 ] = I2C_Read( 1 );
  I2C_Stop();

  return tmp_data[0];                                                           // Return MCP9600 Data value
}

/*******************************************************************************
* Function Read_MCP9600_Status
* ------------------------------------------------------------------------------
* Overview: Function gets Data from MCP9600
* Input: Register address
* Output: Value from desired register
*******************************************************************************/
char Read_MCP9600_Status()
{
  char DataSum;

  tmp_data[0] = MCP9600_Status;                                                 // Register address
  I2C_Start();
  I2C_Write( MCP9600_I2C_ADDR );
  I2C_Write( tmp_data[ 0 ] );
  I2C_Stop();
  Delay_us( 50 );
  I2C_Start();
  I2C_Write( MCP9600_I2C_ADDR | 1 );
  tmp_data[ 0 ] = I2C_Read( 1 );
  I2C_Stop();
  DataSum = tmp_data[0];

  return DataSum;                                                               // Return MCP9600 Data value
}

/*******************************************************************************
* Function Read_Temperature()
* ------------------------------------------------------------------------------
* Overview: Function gets Thermocouple Temperature from MCP9600
* Input: Nothing
* Output: Thermocouple Temperature
*******************************************************************************/
float Read_Temperature()
{
  float Temperature;

  tmp_data[0] = MCP9600_TH;                                                     // Thermocouple Temperature register

  I2C_Start();
  I2C_Write( MCP9600_I2C_ADDR );
  I2C_Write( tmp_data[ 0 ] );
  I2C_Stop();
  Delay_us( 50 );
  I2C_Start();
  I2C_Write( MCP9600_I2C_ADDR | 1 );
  tmp_data[ 0 ] = I2C_Read( 0 );
  tmp_data[ 1 ] = I2C_Read( 1 );
  I2C_Stop();

  if((tmp_data[0] & 0x80) == 0x80){                                             // TA < 0C
    tmp_data[0] = tmp_data[0] & 0x7F;                                           // Clear SIGN
    Temperature = 1024 - (tmp_data[0]*16 + tmp_data[1] / 16);
  }
  else                                                                          // TA > 0C
    Temperature = (tmp_data[0] * 16 + (float)tmp_data[1] / 16);                 // Temperature = Ambient Temperature (C)

  return Temperature;                                                           // Return Thermocouple temperature data
}


